	subroutine tension1der3C1coeff (xx,px,cx,dimx,dim)

!
!   Calculating all de Boor points of the first derivative of the
!   third order Chebyshev tension spline curve
!
!   INPUT:
!       xx    = rank-one double precision array of size dimx, the
!               increasing array of knots, assumed to fulfill the
!               conditions:
!               xx(1)=xx(2)<xx(3)<...<xx(i)<xx(i+1)<...<xx(dimx-1)=
!               xx(dimx); xx(3),...,xx(dimx-2) is the partition of
!               [xx(1),xx(dimx)]; the associated extended
!               partition T has all interior knots of multiplicity 2,
!               and the boundary points of multiplicity 4
!       px    = rank-one double precision array of size dimx-1, the
!               array of tension parameters, assumed to be
!               nonnegative: px(i)>=0 is the tension parameter on
!               the subinterval [xx(i),xx(i+1));
!               px(1) and px(dimx-1) can be arbitrary
!       dimx  = integer variable, the size of the array xx
!       dim   = integer variable, the extent of the first dimension
!               in the array cx, assumed to be positive
!
!   INPUT and OUTPUT:
!       cx    = rank-two double precision array of shape dim by
!               2*dimx-4;
!               ON INPUT: the array of de Boor points of the
!               third order Chebyshev tension spline, associated
!               with the extended partition T;
!               cx(1:dim,i) corresponds to the B-spline with the
!               support [T(i),T(i+3)], so cx(1:dim,1) can be
!               arbitrary
!               ON OUTPUT: the array of de Boor points of the
!               first derivative of the third order Chebyshev
!               tension spline;
!               cx(1:dim,i) corresponds to the B-spline with the
!               support [T(i),T(i+2)] (cx(1:dim,1) and cx(1:dim,2)
!               will not be used)
!

	use functions

	implicit none

	integer, intent(in) :: dimx,dim
	double precision, intent(in) :: xx(dimx),px(dimx-1)	
	double precision, intent(inout) :: cx(dim,2*dimx-4)

	double precision :: h,kc2ph
	integer :: i

!
!	Calculating the de Boor points of the first derivative
!
	do i=dimx-2,2,-1   
		h=xx(i+1)-xx(i)
		kc2ph=h*KC2(px(i)*h/2)/2
		cx(1:dim,2*i)=(cx(1:dim,2*i)-cx(1:dim,2*i-1))/kc2ph
		cx(1:dim,2*i-1)=(cx(1:dim,2*i-1)-cx(1:dim,2*i-2))/kc2ph
	enddo


	end subroutine tension1der3C1coeff